@@ -128,6 +128,10 @@ class urls :
     def options_exp_date(self, stock):
         return f'{self.base_options_url}/quote/option/{stock}/list'
 
+    #new function 22/05/01
+    def options_exp_dat_new(self):
+        return f'{self.base_fintech_gw_url}/quote/option/strategy/list'
+
     def options_bars(self, derivativeId):
         return f'{self.base_options_gw_url}/quote/option/chart/query?derivativeId={derivativeId}'
 
